"use client";
import { DataTableColumnHeader } from "./data-table-column-header";
import { CellAction } from "./cell-action";
import { ColumnDef } from "@tanstack/react-table";
import { Checkbox } from "@/components/ui/checkbox";
import { formatDate } from "@/lib/format-date";
import { Evaluation } from "@/types/evaluation";

export const columns: ColumnDef<Evaluation>[] = [
  {
    id: "select",
    header: ({ table }) => (
      <Checkbox
        checked={
          table.getIsAllPageRowsSelected() ||
          (table.getIsSomePageRowsSelected() && "indeterminate")
        }
        onCheckedChange={(value) => table.toggleAllPageRowsSelected(!!value)}
        aria-label="Select all"
        className="translate-y-[2px]"
      />
    ),
    cell: ({ row }) => (
      <Checkbox
        checked={row.getIsSelected()}
        onCheckedChange={(value) => row.toggleSelected(!!value)}
        aria-label="Select row"
        className="translate-y-[2px]"
      />
    ),
    enableSorting: false,
    enableHiding: false,
  },

  {
    accessorKey: "status",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="STATUS" />
    ),
    cell: ({ row }) => {
      return <p>{row.getValue("status")}</p>;
    },
    filterFn: (row, id, value) => {
      return value.includes(row.getValue(id));
    },
  },

  {
    accessorKey: "uploaderAccount",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="UPLOADER ACCOUNT" />
    ),
    cell: ({ row }) => {
      return <p>{row.getValue("uploaderAccount")}</p>;
    },
  },

  {
    accessorKey: "developerUser",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="DEVELOPER USER" />
    ),
    cell: ({ row }) => {
      return <p>{row.getValue("developerUser")}</p>;
    },
  },

  {
    accessorKey: "uploadTime",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="UPLOAD TIME" />
    ),
    cell: ({ row }) => {
      return <p className="w-fit">{formatDate(row.getValue("uploadTime"))}</p>;
    },
    filterFn: (row, id, value) => {
      return value.includes(row.getValue(id));
    },
  },

  {
    id: "actions",
    header: ({ column }) => (
      <DataTableColumnHeader column={column} title="ACTIONS" />
    ),
    cell: ({ row }) => <CellAction data={row.original} />,
  },
];
